16.93. cdist-type__package_emerge(7) — cdist 4.10.11 documentation

# 16.93. cdist-type__package_emerge(7)

## 16.93.1. NAME

cdist-type__package_emerge - Manage packages with portage

## 16.93.2. DESCRIPTION

Portage is usually used on the gentoo distribution to manage packages. This type requires app-portage/gentoolkit installed on the target host. cdist-type__package_emerge_dependencies is supposed to install the needed packages on the target host.

## 16.93.3. REQUIRED PARAMETERS

None

## 16.93.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present".
version
  If supplied, use to install or uninstall a specific version of the package named.

## 16.93.5. EXAMPLES

    # Ensure sys-devel/gcc is installed
    __package_emerge sys-devel/gcc --state present

    # If you want a specific version of a package
    __package_emerge app-portage/gentoolkit --state present --version 0.3.0.8-r2

    # Remove package
    __package_emerge sys-devel/gcc --state absent

## 16.93.6. SEE ALSO

cdist-type__package(7), cdist-type__package_emerge_dependencies(7)

## 16.93.7. AUTHORS

Thomas Oettli <otho--@--sfs.biz>

## 16.93.8. COPYING

Copyright (C) 2013 Thomas Oettli. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.